<template>
  <div class="mod-config">
    <basic-container>
      <ttable
        :table="table"
        @handleSelectionChange="handleSelectionChange"
        :uploadInfo="uploadInfo"
        :prelang="prelang"
        :options="options"
        :ajaxFun="ajaxFun"
        ref="spotcheckruleTable"
      >
        <template #toolbar></template>
      </ttable>
      <!-- 弹窗, 新增 / 修改 -->
      <table-form
        v-if="addOrUpdateVisible"
        ref="addOrUpdate"
        @refreshDataList="getData"
      ></table-form>
    </basic-container>
  </div>
</template>

<script>
import {
  fetchListSamplingRule,
  delSamplingRule
} from '@/api/quality/samplingrule'
import TableForm from './spotcheckrule-form'
import { mapGetters } from 'vuex'
import ttable from '@/views/common/ztt-table.vue'
import { remote } from '@/api/admin/dict'

export default {
  data() {
    return {
      ajaxFun: fetchListSamplingRule,
      addOrUpdateVisible: false,
      multipleSelection: [],
      uploadInfo: {
        // 是否展示上传EXCEL以及对应的url
        isShow: false,
        url: ''
      },
      prelang: 'spotcheckrule',
      options: {
        height: 300, // 默认高度-为了表头固定
        stripe: true, // 是否为斑马纹 table
        highlightCurrentRow: false, // 是否要高亮当前行
        border: true, // 是否有纵向边框
        lazy: false, // 是否需要懒加载
        fit: true, // 列的宽度是否自撑开
        multiSelect: true, //
        seqNo: true,
        isRefresh: true, // 是否显示刷新按钮
        isShowHide: true, // 是否显示显影按钮
        isSearch: false, // 高级查询按钮
        defaultOrderBy: { column: 'id', direction: 'desc' }
      },
      table: {
        total: 0,
        currentPage: 1,
        pageSize: 20,
        data: [],
        // 标题
        column: [
          // 规则编号
          {
            minWidth: '30',
            prop: 'ruleNo',
            label: '规则编号',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text',
            render: { fun: this.addOrUpdateHandle }
          },
          // 规则名称
          {
            minWidth: '120',
            prop: 'ruleName',
            label: '规则名称',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          // 抽检工序
          {
            minWidth: '120',
            prop: 'samplingOperationName',
            label: '抽检工序',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          // 追溯工序
          {
            minWidth: '120',
            prop: 'retrospectOperationName',
            label: '追溯工序',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          // 检测类型
          {
            minWidth: '120',
            prop: 'applyType',
            label: '检测类型',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'select',
            optList: () => {
              return this.getReportTypeOptions()
            },
            formatter: (row, column, cellValue) => {
              this.reportTypeOptions.forEach((obj) => {
                if (obj.value === cellValue) {
                  cellValue = obj.label
                }
              })
              return cellValue
            }
          },
          // 抽检比例
          {
            minWidth: '120',
            prop: 'measurement',
            label: '抽检比例',
            sort: true,
            isTrue: true,
            isSearch: false,
            searchInfoType: 'text',
            formatter: (row, column, cellValue) => {
              const formatVal =
                row.samplingNumerator + '/' + row.samplingDenominator
              return formatVal
            }
          },
          // 抽检位置
          {
            minWidth: '120',
            prop: 'samplingPosition',
            label: '抽检位置',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          }
        ],
        toolbar: [
          {
            text: '新增',
            type: 'primary',
            fun: this.addOrUpdateHandle
          }
        ],
        operator: [
          {
            text: '删除',
            type: 'text',
            size: 'small',
            fun: this.deleteHandle
          }
        ],
        operatorConfig: {
          fixed: 'right',
          label: '操作',
          width: 100,
          minWidth: 100
        }
      },
      textureOptions: [],
      reportTypeOptions: []
    }
  },
  components: {
    TableForm,
    ttable
  },
  computed: {
    ...mapGetters(['permissions'])
  },
  methods: {
    // 获取数据列表
    getData() {
      this.$refs.spotcheckruleTable.getDataList()
    },
    // 新增 / 修改
    addOrUpdateHandle(row) {
      this.addOrUpdateVisible = true
      this.$nextTick(() => {
        this.$refs.addOrUpdate.init(row == null ? null : row.id)
      })
    },
    // 删除
    deleteHandle(row) {
      this.$confirm('是否确认删除规则编号为：' + row.ruleNo, '提示', {
        confirmButtonText: '确定',
        cancelButtonText: '取消',
        closeOnClickModal: false,
        type: 'warning'
      })
        .then(function() {
          return delSamplingRule(row.id)
        })
        .then((data) => {
          this.$message.success('删除成功')
          this.getData()
        })
    },
    handleSelectionChange(val) {
      this.multipleSelection = val
    },
    initReportTypeSelect() {
      remote('apply_report_type').then((response) => {
        const code = response.data.code
        if (code === 0) {
          const _data = response.data.data
          this.reportTypeOptions = _data
        }
      })
    },
    getReportTypeOptions() {
      return this.reportTypeOptions
    }
  },
  created() {
    this.initReportTypeSelect()
  }
}
</script>
